"""
Image Processing Module
"""

# Import submodules for easier access
from .prac1 import *
from .prac2 import *
from .prac3 import *
from .prac4 import *
from .prac5 import *
from .prac6 import *
from .prac7 import *